"use strict";
cc._RF.push(module, 'c632ar6VQ5IuJ+Y3uG0TZyv', 'EventManager');
// scripts/EventManager.ts

"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 全局事件管理器
 */
var EventManager = /** @class */ (function () {
    function EventManager() {
        // 已经注册事件集合
        this._events = new Map();
    }
    /**
     * 注册事件
     * @param type 事件类型
     * @param callback 处理回调
     * @param target 目标对象
     */
    EventManager.prototype.on = function (type, callback, target) {
        var events = this._events.get(type);
        if (!events) {
            events = new Map();
            this._events.set(type, events);
        }
        events.set(target, { on: callback, target: target });
    };
    /**
     * 注销事件
     * @param type 事件类型
     * @param target 目标对象
     */
    EventManager.prototype.off = function (type, target) {
        var events = this._events.get(type);
        if (events) {
            events.delete(target);
        }
    };
    /**
     * 发送事件
     * @param type 事件类型
     * @param arg1 传递的参数
     * @param arg2
     * @param arg3
     * @param arg4
     * @param arg5
     */
    EventManager.prototype.emit = function (type, arg1, arg2, arg3, arg4, arg5) {
        var events = this._events.get(type);
        if (events) {
            events.forEach(function (event) { return event.on.call(event.target, arg1, arg2, arg3, arg4, arg5); });
        }
    };
    EventManager.getInstance = function () {
        if (!EventManager._instance) {
            EventManager._instance = new EventManager();
        }
        return EventManager._instance;
    };
    /**
     * 事件管理器实例
     */
    EventManager._instance = null;
    return EventManager;
}());
exports.default = EventManager;

cc._RF.pop();